Learn R Programming

SSRTcalc (version 2.1.1)

adaptive: Example adaptive stop-signal task data

Description

A long-format dataset from a stop-signal task using an adaptive (staircase-tracking) stop-signal delay, suitable for demonstrating every function in SSRTcalc.

Usage

adaptive

Arguments

Format

A data frame with 4000 rows (20 subjects x 200 trials) and 6 columns:

SubjID

Integer subject identifier (1-20).

trial

Integer trial number within subject (1-200).

vol

Trial type: 0 = go trial, 1 = stop trial.

RT_exp

Observed reaction time in milliseconds. NA on successfully inhibited stop trials.

correct

Accuracy indicator (1 = correct response on go trials, or successful inhibition on stop trials; 0 otherwise).

soa

Stop-signal delay (SOA) in milliseconds for stop trials; NA on go trials. Adjusted trial-by-trial by a staircase algorithm to track ~50% inhibition.

Examples

Run this code
data(adaptive)
d <- adaptive[adaptive$SubjID == 1, ]
integration_adaptiveSSD(d)

Run the code above in your browser using DataLab