Learn R Programming

SSRTcalc (version 2.1.1)

run_all_mc: Run all four Monte Carlo analyses in one call

Description

Run all four Monte Carlo analyses in one call

Usage

run_all_mc(
  data,
  n_iter = 1000,
  seed = 42,
  stop_col = "vol",
  rt_col = "RT_exp",
  acc_col = "correct",
  ssd_col = "soa"
)

Value

Named list: bootstrap, simulation, power, robustness.

Arguments

data

data.frame in SSRTcalc long format.

n_iter

Iterations (shared). Default 1000.

seed

Random seed. Default 42.

stop_col, rt_col, acc_col, ssd_col

Column names.

Examples

Run this code
if (FALSE) {
data(adaptive)
d <- adaptive[adaptive$SubjID == 1, ]
res <- run_all_mc(d, n_iter=500)
}

Run the code above in your browser using DataLab